@@ -7,6 +7,7 @@ from __future__ import annotations
 from typing import Literal
 
 
+# DOC: add custom type in docstring of constant or types
 # ============================================================================ #
 #                                     TYPES                                    #
 # ============================================================================ #
@@ -14,6 +15,7 @@ from typing import Literal
 #   - Base
 #   - Reads
 #   - Overlaps
+
 # ---------------------------------------------------------------------------- #
 #                                     Base                                     #
 # ---------------------------------------------------------------------------- #
@@ -21,36 +23,58 @@ IndexT = int
 """Indices type."""
 
 OrT = Literal[0, 1]
-"""Orientations type."""
+"""Orientations type.
+
+Binary value
+"""
+
 # ---------------------------------------------------------------------------- #
 #                                   Oriented                                   #
 # ---------------------------------------------------------------------------- #
 IndOrT = tuple[IndexT, OrT]
-"""Vertices type."""
+"""Vertices type.
+
+type: :class:`tuple` (:data:`IndexT`, :data:`OrT`)
+"""
 
 EIndOrT = tuple[IndOrT, IndOrT]
-"""Edges type."""
+"""Edges type with no edge index.
+
+type: :class:`tuple` (:data:`IndOrT`, :data:`IndOrT`)
+"""
 
-# DOC: change doc and remove EIndorT
 EIndOrIndT = tuple[IndOrT, IndOrT, IndexT]
-"""Edges with edge index type."""
+"""Edges with edge index type.
+
+type: :class:`tuple` (:data:`IndOrT`, :data:`IndOrT`, :data:`IndexT`)
+"""
 
 IndOrIndT = tuple[IndOrT, IndexT]
-"""Adjacent vertex with edge index type."""
+"""Adjacent vertex with edge index type.
+
+type: :class:`tuple` (:data:`IndOrT`, :data:`IndexT`)
+"""
+
 # ---------------------------------------------------------------------------- #
-#                                  Unoriented                                  #
+#                                 Non-oriented                                 #
 # ---------------------------------------------------------------------------- #
-# DOC: do doc EIndT
 EIndT = tuple[IndexT, IndexT]
-"""Edges of indices type."""
+"""Edges of indices type.
+
+type: :class:`tuple` (:data:`IndexT`, :data:`IndexT`)
+"""
 
-# DOC: do doc EIndIndT
 EIndIndT = tuple[IndexT, IndexT, IndexT]
-"""Edges of indices with edge index type."""
+"""Edges of indices with edge index type.
+
+type: :class:`tuple` (:data:`IndexT`, :data:`IndexT`, :data:`IndexT`)
+"""
 
-# DOC: do doc IndIndT
 IndIndT = tuple[IndexT, IndexT]
-"""Adjacent index vertex with edge index type."""
+"""Adjacent index vertex with edge index type.
+
+type: :class:`tuple` (:data:`IndexT`, :data:`IndexT`)
+"""
 
 # ============================================================================ #
 #                                   CONSTANTS                                  #
@@ -88,6 +112,7 @@ FWDOR_REVOR: tuple[tuple[OrT, OrT], tuple[OrT, OrT]] = (
 
 type: :class:`tuple` ((:data:`OrT`, :data:`OrT`), (:data:`OrT`, :data:`OrT`))
 """
+
 # ---------------------------------------------------------------------------- #
 #                                Oriented Vertex                               #
 # ---------------------------------------------------------------------------- #
@@ -95,20 +120,23 @@ IND: Literal[0] = 0
 """The index for :data:`IndOrT`'s index value."""
 OR: Literal[1] = 1
 """The index for :data:`IndOrT`'s orientation value."""
+
 # ---------------------------------------------------------------------------- #
-#                                Adjancies Table                               #
+#                               Adjacencies Table                              #
 # ---------------------------------------------------------------------------- #
 PRED_IND: Literal[0] = 0
 """The index for predecessors of forwards in adjancies table"""
 SUCC_IND: Literal[1] = 1
 """The index for successors of forwards in adjancies table"""
+
 # ---------------------------------------------------------------------------- #
-#                                 Adjancy Type                                 #
+#                                Adjacency Type                                #
 # ---------------------------------------------------------------------------- #
 ADJ_INDOR: Literal[0] = 0
 """The index for :data:`IndOrT` value in :data:`IndOrIndT`."""
 ADJ_IND: Literal[1] = 1
 """The index for :data:`IndexT` value in :data:`IndOrIndT`."""
+
 # ---------------------------------------------------------------------------- #
 #                             Edges And Edge Index                             #
 # ---------------------------------------------------------------------------- #
@@ -124,15 +152,17 @@ E_IND: Literal[2] = 2
 For both :data:`EIndOrIndT` and :data:`EIndIndT` it corresponds to
 :data:`IndexT` value.
 """
+
 # ---------------------------------------------------------------------------- #
 #                                 Miscellaneous                                #
 # ---------------------------------------------------------------------------- #
 MULT_IID: Literal[2] = 2
 """Index multiplier."""
+# XXX: necessary?
 
 
 # ============================================================================ #
-#                                   FONCTIONS                                  #
+#                                   FUNCTIONS                                  #
 # ============================================================================ #
 # ---------------------------------------------------------------------------- #
 #                                    IndOrT                                    #
